@@ -2,6 +2,6 @@ import {expectType, expectError} from 'tsd';
 import {ReadonlyDeep} from 'type-fest';
 import globals = require('.');
 
-expectType<ReadonlyDeep<{[key: string]: {[key: string]: boolean}}>>(globals);
+expectType<ReadonlyDeep<Record<string, Record<string, boolean>>>>(globals);
 expectType<boolean>(globals.builtin.Array);
 expectError((globals.builtin.Array = true));
